@@ -467,8 +467,10 @@ OENTRY opcodlst_1[] = {
   { "rand.k",   S(RAND),0,    3,      "k",    "xvoo", rndset, krand,  NULL  },
   { "randh",  S(RANDH),0,   3,      "a",    "xxvoo", rhset, randh   },
   { "randh.k",  S(RANDH),0,   3,      "k",    "xxvoo", rhset, krandh, NULL   },
-  { "randi",  S(RANDI),0,   3,      "a",    "xxvoo", riset, randi   },
-  { "randi.k",  S(RANDI),0,   3,      "k",    "xxvoo", riset, krandi, NULL  },
+  { "randi",  S(RANDI),0,   3,      "a",    "xxvoo", riset, randi     },
+  { "randi.k",  S(RANDI),0, 3,      "k",    "xxvoo", riset, krandi    },
+  { "randc",  S(RANDC),0,   3,      "a",    "xxvoo", rcset, randc     },
+  { "randc.k",  S(RANDC),0, 3,      "k",    "xxvoo", rcset, krandc    },
   { "port",   S(PORT),0,    3,      "k",    "kio",  porset, port            },
   { "tone.k", S(TONE),0,    3,      "a",    "ako",  tonset,   tone    },
   { "tonex.k",S(TONEX),0,   3,      "a",    "akoo", tonsetx,  tonex   },
@@ -793,6 +795,16 @@ OENTRY opcodlst_1[] = {
     schedule_S, NULL, NULL },
   { "schedule.SN", S(SCHED),0,  1,     "",     "SiiN",
     schedule_SN, NULL, NULL },
+  /* **** Experimental schedulek opcodes **** */
+  { "schedulek",   S(SCHED),0,  2,     "",     "kkkM",
+    NULL, schedule, NULL },
+  { "schedulek.N", S(SCHED),0,  2,     "",     "kkkN",
+    NULL, schedule_N, NULL },
+  { "schedulek.S", S(SCHED),0,  2,     "",     "SkkM",
+    NULL, schedule_S, NULL },
+  { "schedulek.SN", S(SCHED),0, 2,     "",     "SkkN",
+    NULL, schedule_SN, NULL },
+  /* **** End of schedulek **** */
   { "schedwhen", S(WSCHED),0,3,     "",     "kkkkm",ifschedule, kschedule, NULL },
   { "schedwhen", S(WSCHED),0,3,     "",     "kSkkm",ifschedule, kschedule, NULL },
   { "schedkwhen", S(TRIGINSTR),0, 3,"",     "kkkkkz",triginset, ktriginstr, NULL },
@@ -1065,6 +1077,14 @@ OENTRY opcodlst_1[] = {
     (SUBR) chnget_opcode_init_i, NULL, NULL               },
   { "chnget.k",    S(CHNGET),_CR,           3,      "k",            "S",
     (SUBR) chnget_opcode_init_k, (SUBR) notinit_opcode_stub, NULL },
+  { "chngeti.i",    S(CHNGET),_CR,           1,      "i[]",            "S[]",
+    (SUBR) chnget_array_opcode_init_i, NULL, NULL               },
+  { "chngeta.a",    S(CHNGET),_CR,           3,      "a[]",            "S[]",
+    (SUBR) chnget_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
+  { "chngets.s",    S(CHNGET),_CR,           3,      "S[]",            "S[]",
+    (SUBR) chnget_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
+  { "chngetk.k",    S(CHNGET),_CR,           3,      "k[]",            "S[]",
+    (SUBR) chnget_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
   { "chnget.a",    S(CHNGET),_CR,           3,      "a",            "S",
     (SUBR) chnget_opcode_init_a, (SUBR) notinit_opcode_stub },
   { "chnget.S",    S(CHNGET),_CR,           3,      "S",            "S",
@@ -1072,6 +1092,16 @@ OENTRY opcodlst_1[] = {
   { "chngetks",    S(CHNGET),_CR,           2,      "S",            "S",
     NULL, (SUBR) chnget_opcode_perf_S, NULL},
   //{ "chnset",      0xFFFB,              _CW                               },
+
+  { "chnseti.i",    S(CHNGET),_CW,          1,      "",             "i[]S[]",
+    (SUBR) chnset_array_opcode_init_i, NULL, NULL               },
+  { "chnsetk.k",    S(CHNGET),_CW,           3,      "",             "k[]S[]",
+    (SUBR) chnset_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
+  { "chnseta.a",    S(CHNGET),_CW,           3,      "",             "a[]S[]",
+    (SUBR) chnset_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
+  { "chnsets.s",    S(CHNGET),_CW,           3,      "",             "S[]S[]",
+    (SUBR) chnset_array_opcode_init, (SUBR) notinit_opcode_stub, NULL },
+
   { "chnset.i",    S(CHNGET),_CW,          1,      "",             "iS",
     (SUBR) chnset_opcode_init_i, NULL, NULL               },
   //  { "chnset.r",    S(CHNGET),0,           1,      "",             "iS",
