@@ -211,7 +211,7 @@ int32_t phsor(CSOUND *csound, PHSOR *p)
 
 static int32_t itblchk(CSOUND *csound, TABLE *p)
 {
-    if (UNLIKELY((p->ftp = csound->FTnp2Find(csound, p->xfn)) == NULL))
+    if (UNLIKELY((p->ftp = csound->FTnp2Finde(csound, p->xfn)) == NULL))
       return NOTOK;
 
     /* Although TABLE has an integer variable for the table number
@@ -1088,7 +1088,7 @@ int32_t kosc1i(CSOUND *csound, OSCIL1   *p)
 int32_t oscnset(CSOUND *csound, OSCILN *p)
 {
     FUNC        *ftp;
-    if (LIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) != NULL)) {
+    if (LIKELY((ftp = csound->FTnp2Finde(csound, p->ifn)) != NULL)) {
       p->ftp = ftp;
       p->inc = ftp->flen * *p->ifrq * csound->onedsr;
       p->index = FL(0.0);
