@@ -337,7 +337,7 @@ static int32_t Xsynthset(CSOUND *csound, CON *p)
     p->in1 = b;            b += 2 * flen;
     p->in2 = b;            b += 2 * flen;
 
-    if ((ftp = csound->FTnp2Find(csound, p->iwin)) != NULL)
+    if ((ftp = csound->FTnp2Finde(csound, p->iwin)) != NULL)
       p->win = ftp;
     else return NOTOK;
 
