@@ -1,3 +1,4 @@
+
 /*
     ftgen.c:
 
@@ -37,7 +38,7 @@ typedef struct {
 
 typedef struct {
     OPDS    h;
-    MYFLT   *ifilno, *iflag, *argums[VARGMAX];
+    MYFLT   *ifilno, *iflag, *argums[VARGMAX-2];
 } FTLOAD;  /* gab 30 jul 2002 */
 
 typedef struct {
@@ -261,13 +262,13 @@ static int32_t ftload_(CSOUND *csound, FTLOAD *p, int32_t istring)
     FUNC  *(*ft_func)(CSOUND *, MYFLT *);
     void  *fd;
 
-    if (strncmp(csound->GetOpcodeName(p), "ftload", 6) != 0) {
+    if (strncmp(csound->GetOpcodeName(p), "ftloadk", 7) == 0) {
       nargs--;
       ft_func = csound->FTFindP;
       err_func = csound->PerfError;
     }
     else {
-      ft_func = csound->FTnp2Find;
+      ft_func = csound->FTnp2Finde;
       err_func = myInitError;
     }
 
@@ -503,7 +504,7 @@ static int32_t ftsave_(CSOUND *csound, FTLOAD *p, int32_t istring)
     }
     else {
       nargs = csound->GetInputArgCnt(p) - 2;
-      ft_func = csound->FTnp2Find;
+      ft_func = csound->FTnp2Finde;
       err_func = myInitError;
     }
 
@@ -682,7 +683,7 @@ static int32_t ftgen_list(CSOUND *csound, FTGEN *p, int32_t istring)
       n = array->sizes[0];
       ftevt->pcnt = (int16) n+4;
       int32_t i = 0;
-      memcpy(&fp[5], array->data, n*sizeof(MYFLT));
+      memcpy(&fp[5], &array->data[0], n*sizeof(MYFLT));
       while (i < n) {
         i++;
       }
@@ -727,7 +728,7 @@ static OENTRY localops[] = {
                                                   (SUBR) ftsave_kS, NULL       },
   { "ftloadk",  S(FTLOAD_K),  TW, 3,  "",   "ikim",   (SUBR) ftsave_k_set,
     (SUBR) ftload_k, NULL       },
- { "ftloadk.S",  S(FTLOAD_K),  TW, 3,  "",   "Skim",   (SUBR) ftsave_k_set,
+  { "ftloadk.S",  S(FTLOAD_K),  TW, 3,  "",   "Skim",   (SUBR) ftsave_k_set,
                                                   (SUBR) ftload_kS, NULL       }
 };
 
