@@ -42,7 +42,7 @@ const double twopi = TWOPI;
 
 /** opcode threads: i-time, k-perf and/or a-perf
 */
-enum thread { i = 1, k = 2, ik = 3, a = 2, ia = 3 /*, ika = 3*/ };
+enum thread { i = 1, k = 2, ik = 3, a = 4, ia = 5 /*, ika = 3*/ };
 
 /** fsig formats: phase vocoder, stft polar, stft complex, or
     sinusoidal tracks
@@ -244,6 +244,30 @@ public:
     return reinterpret_cast<std::complex<MYFLT> *>(fdata);
   }
 
+  /** Creates a global variable in the current Csound object
+  */
+  int create_global_variable(const char *name, size_t nbytes) {
+    return CreateGlobalVariable(this, name, nbytes);
+  }
+
+  /** Retrieves a ptr for an existing named global variable
+   */
+  void *query_global_variable(const char* name) {
+    return QueryGlobalVariable(this, name);
+  }
+
+  /** Destroy an existing named global variable
+   */
+  int destroy_global_variable(const char* name) {
+     return DestroyGlobalVariable(this, name);
+  }
+
+  /** Access to the base CSOUND object
+   */
+  CSOUND *get_csound() {
+    return this;
+  }
+
   /** Sleep
    */
   void sleep(int ms) { Sleep(ms); }
@@ -569,6 +593,10 @@ public:
    */
   int fsig_format() { return format; }
 
+  /** get data frame as floats
+   */
+  float *data() { return (float *) frame.auxp; }
+
   /** convert to pv_frame ref
    */
   operator pv_frame &() { return reinterpret_cast<pv_frame &>(*this); }
@@ -578,6 +606,7 @@ public:
    */
   operator spv_frame &() { return reinterpret_cast<spv_frame &>(*this); }
 #endif
+
 };
 
 /**  Container class for a Phase Vocoder
@@ -649,7 +678,7 @@ public:
   /** Initialise this object from an opcode
       argument arg */
   int init(Csound *csound, MYFLT *arg) {
-    Table *f = (Table *)csound->FTnp2Find(csound, arg);
+    Table *f = (Table *)csound->FTnp2Finde(csound, arg);
     if (f != nullptr) {
       std::copy(f, f + 1, this);
       return OK;
@@ -853,8 +882,120 @@ public:
   myfltvec &myfltvec_data(int n) { return (myfltvec &)*ptrs[n]; }
 };
 
+/** InPlug template base class:
+    for 0 outputs and N inputs
+    also for multiple outputs and/or inputs
+ */
+template <std::size_t N> struct InPlug : OPDS {
+  /** arguments */
+  Param<N> args;
+  /** Csound engine */
+  Csound *csound;
+  /** sample-accurate offset */
+  uint32_t offset;
+  /** vector samples to process */
+  uint32_t nsmps;
+
+  /** i-time function placeholder
+   */
+  int init() { return OK; }
+
+  /** k-rate function placeholder
+   */
+  int kperf() { return OK; }
+
+  /** a-rate function placeholder
+   */
+  int aperf() { return OK; }
+
+  /** @private
+      sample-accurate offset for
+      a-rate opcodes; updates offset
+      and nsmps. Called implicitly by
+      the aperf() method.
+   */
+  void sa_offset() {
+    uint32_t early = insdshead->ksmps_no_end;
+    nsmps = insdshead->ksmps - early;
+    offset = insdshead->ksmps_offset;
+  }
+
+  /** @private
+      set nsmps and offset value for kperf()
+   */
+  void nsmps_set() {
+    nsmps = insdshead->ksmps - insdshead->ksmps_no_end;
+    offset = insdshead->ksmps_offset;
+  }
+
+  /** returns the number of output arguments
+      used in the case of variable output count
+  */
+  uint32_t out_count() { return (uint32_t)optext->t.outArgCount; }
+
+  /** returns the number of input arguments
+      used in the case of variable input count
+  */
+  uint32_t in_count() { return (uint32_t)optext->t.inArgCount; }
+
+  /** local control rate
+   */
+  MYFLT kr() { return insdshead->ekr; }
+
+  /** local ksmps
+   */
+  MYFLT ksmps() { return insdshead->ksmps; }
+
+   /** sampling rate
+   */
+  MYFLT sr() { return csound->sr(); }
+
+  /** midi channel number for this instrument
+   */
+  int midi_channel() { return ((CSOUND *)csound)->GetMidiChannelNumber(this); }
+
+  /** midi note number for this instrument
+   */
+  int midi_note_num() { return ((CSOUND *)csound)->GetMidiNoteNumber(this); }
+
+  /** midi note velocity for this instrument
+   */
+  int midi_note_vel() { return ((CSOUND *)csound)->GetMidiVelocity(this); }
+
+  /** midi aftertouch for this channel
+   */
+  MYFLT midi_chn_aftertouch() {
+    return ((CSOUND *)csound)->GetMidiChannel(this)->aftouch; }
+
+  /** midi poly aftertouch for this channel
+   */
+  MYFLT midi_chn_polytouch(uint32_t note) {
+    return ((CSOUND *)csound)->GetMidiChannel(this)->polyaft[note];
+  }
+
+  /** midi ctl change for this channel
+   */
+  MYFLT midi_chn_ctl(uint32_t ctl) {
+    return ((CSOUND *)csound)->GetMidiChannel(this)->ctl_val[ctl];
+  }
+
+  /** midi pitchbend for this channel
+   */
+  MYFLT midi_chn_pitchbend() {
+    return ((CSOUND *)csound)->GetMidiChannel(this)->pchbend; }
+
+  /** list of active instrument instances for this channel \n
+      returns an INSDS array with 128 items, one per
+      MIDI note number. Inactive instances are marked NULL.
+   */
+  const INSDS *midi_chn_list() {
+    return (const INSDS *) ((CSOUND *)csound)->GetMidiChannel(this)->kinsptr;
+  }
+
+};
+
 /** Plugin template base class:
-    N outputs and M inputs
+    for N outputs and M inputs, N > 0
  */
 template <std::size_t N, std::size_t M> struct Plugin : OPDS {
   /** output arguments */
@@ -903,7 +1044,7 @@ template <std::size_t N, std::size_t M> struct Plugin : OPDS {
       set nsmps and offset value for kperf()
    */
   void nsmps_set() {
-    nsmps = insdshead->ksmps - insdshead->ksmps_no_end;;
+    nsmps = insdshead->ksmps - insdshead->ksmps_no_end;
     offset = insdshead->ksmps_offset;
   }
 
@@ -921,6 +1062,14 @@ template <std::size_t N, std::size_t M> struct Plugin : OPDS {
    */
   MYFLT kr() { return insdshead->ekr; }
 
+ /** local ksmps
+   */
+  MYFLT ksmps() { return insdshead->ksmps; }
+
+   /** sampling rate
+   */
+  MYFLT sr() { return csound->sr(); }
+
   /** midi channel number for this instrument
    */
   int midi_channel() { return ((CSOUND *)csound)->GetMidiChannelNumber(this); }
@@ -967,7 +1116,7 @@ template <std::size_t N, std::size_t M> struct Plugin : OPDS {
 
 
 /** Fsig plugin template base class:
-    N outputs and M inputs
+    for N outputs and M inputs
  */
 template <std::size_t N, std::size_t M> struct FPlugin : Plugin<N, M> {
   /** current frame time index */
@@ -1009,10 +1158,12 @@ template <typename T>
 int plugin(Csound *csound, const char *name, const char *oargs,
            const char *iargs, uint32_t thr, uint32_t flags = 0) {
   CSOUND *cs = (CSOUND *)csound;
-  if(thr == thread::ia || thr == thread::a)
+  if(thr == thread::ia || thr == thread::a) {
+  thr = thr == thread::ia ? 3 : 2;
   return cs->AppendOpcode(cs, (char *)name, sizeof(T), flags, thr,
                           (char *)oargs, (char *)iargs, (SUBR)init<T>,
                           (SUBR)aperf<T>, NULL);
+  }
   else
   return cs->AppendOpcode(cs, (char *)name, sizeof(T), flags, thr,
                           (char *)oargs, (char *)iargs, (SUBR)init<T>,
@@ -1026,10 +1177,13 @@ template <typename T>
 int plugin(Csound *csound, const char *name, uint32_t thr,
            uint32_t flags = 0) {
   CSOUND *cs = (CSOUND *)csound;
-  if(thr == thread::ia || thr == thread::a)
+  if(thr == thread::ia || thr == thread::a) {
+  thr = thr == thread::ia ? 3 : 2;
   return cs->AppendOpcode(cs, (char *)name, sizeof(T), flags, thr,
                           (char *)T::otypes, (char *)T::itypes, (SUBR)init<T>,
                           (SUBR)aperf<T>, NULL);
+
+  }
   else
   return cs->AppendOpcode(cs, (char *)name, sizeof(T), flags, thr,
                           (char *)T::otypes, (char *)T::itypes, (SUBR)init<T>,
